@@ -1,4 +1,5 @@
 """ subpackage holding modules with tools """
 
 from . import collection, date, dictionary, ee_list, featurecollection, \
-              geometry, image, imagecollection, number, string, array
\ No newline at end of file
+              geometry, image, imagecollection, number, string, array, \
+              computedobject, element
\ No newline at end of file
